@@ -21,6 +21,10 @@ class RunConfig:
     verbosity: int = 0
     slowdown: float = 1
     unlimited_registers: bool = False
-
-
-CONFIG = RunConfig()
+    flen: int = 64
+    # runtime config
+    use_libc: bool = False
+    ignore_exit_code: bool = False
+    # csr stuff:
+    # frequency of the real-time clock
+    rtclock_tickrate: int = 32768
